package org.branulf.nevergonnaplayer;

import javax.swing.*;
import java.awt.*;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.URL;
import java.nio.file.Files;
import java.nio.file.Path;
import java.nio.file.Paths;

public class MainApplication {
    private static final String VIDEO_URL = "https://branulf.top/files/rickroll.mp4";
    private static final String VIDEO_NAME = "never_gonna_give_you_up.mp4";

    public static void main(String[] args) {
        try {
            Path tempDir = Paths.get(System.getProperty("java.io.tmpdir"), "JVAV_TEMP");
            Files.createDirectories(tempDir);

            Path videoPath = tempDir.resolve(VIDEO_NAME);

            if (!Files.exists(videoPath)) {
                downloadVideo(videoPath);
            }

            openWithDefaultPlayer(videoPath);

        } catch (Exception e) {
            showErrorDialog("程序出错: " + e.getMessage());
        }
    }

    private static void downloadVideo(Path savePath) throws Exception {
        JFrame progressFrame = new JFrame("JVAV安装程序");
        progressFrame.setSize(300, 100);
        progressFrame.setDefaultCloseOperation(JFrame.DO_NOTHING_ON_CLOSE);
        progressFrame.setLocationRelativeTo(null);

        JProgressBar progressBar = new JProgressBar(0, 100);
        progressBar.setStringPainted(true);

        JLabel label = new JLabel("JVAV将会自动安装...", SwingConstants.CENTER);

        progressFrame.setLayout(new BorderLayout());
        progressFrame.add(label, BorderLayout.NORTH);
        progressFrame.add(progressBar, BorderLayout.CENTER);
        progressFrame.setVisible(true);

        try (InputStream in = new URL(VIDEO_URL).openStream();
             FileOutputStream out = new FileOutputStream(savePath.toFile())) {

            byte[] buffer = new byte[8192];
            int bytesRead;
            long totalBytesRead = 0;
            long totalBytes = in.available();

            while ((bytesRead = in.read(buffer)) != -1) {
                out.write(buffer, 0, bytesRead);
                totalBytesRead += bytesRead;

                // 更新进度条
                int progress = (int) ((totalBytesRead * 100) / totalBytes);
                SwingUtilities.invokeLater(() -> {
                    progressBar.setValue(progress);
                    label.setText(String.format("下载中: %d%%", progress));
                });
            }
        } finally {
            progressFrame.dispose();
        }
    }

    private static void openWithDefaultPlayer(Path videoPath) {
        try {
            Desktop desktop = Desktop.getDesktop();
            if (desktop.isSupported(Desktop.Action.OPEN)) {
                desktop.open(videoPath.toFile());
            } else {
                showErrorDialog("无法安装JVAV依赖库");
            }
        } catch (Exception e) {
            showErrorDialog("无法安装JVAV: " + e.getMessage());
        }
    }

    private static void showErrorDialog(String message) {
        JOptionPane.showMessageDialog(null, message, "错误", JOptionPane.ERROR_MESSAGE);
    }
}
